==> cmsmadesimple-1.5.3-full.tar.gz: modules/ThemeManager/lang/ext/nb_NO.php <==
<?php
$lang['error_uploadpermissions'] = '<strong>ADVARSEL:</strong> Du har ikke tilstrekkelige rettigheter for &aring; laste opp eller installere temaer. Dette kan bero p&aring; restriksjoner satt p&aring; opplasting eller modulers underkataloger, eller ogs&aring; s&aring; kan Safe mode v&aelig;re aktivert p&aring; serveren.';
$lang['error_nomenumanager'] = 'MenuManager modulen ikke funnet';
$lang['active'] = 'Aktiv';
$lang['default'] = 'Standard';
$lang['prompt_themename'] = 'Eksporter Tema som:';
$lang['info_themename'] = 'Dette feltet bestemmer utg&aring;ende tema-navn, uavhengig av inng&aring;ende tema-navn';
$lang['error_editingproblem'] = 'Problem med &aring; rense opp og endre reffererte filer i dette tema&#039;et';
$lang['error_problemsavingincludes'] = 'Problem med &aring; lagere de enkodede filene i dette temaet..';
$lang['error_nofilesuploaded'] = 'Ingen filer ble lastet opp. Sjekk at din skjema tagg&#039;s enctype var satt til multipart/form-data og at korrekt felt er blitt haket av for den opplastede fila.';
$lang['error_templateexists'] = 'En mal med navnet &quot;%s&quot; eksisterer allerede';
$lang['error_stylesheetexists'] = 'Et stilsett med navnet &quot;%s&quot; eksisterer allerede';
$lang['error_nostylesheets'] = 'Ingen stilsett ble funnet i dette temaet';
$lang['error_couldnotcreatetemplate'] = 'Kunne ikke opprette mal-definisjonen';
$lang['error_couldnotassoccss'] = 'Problem med &aring; assosiere stilsett med malen';
$lang['error_nooutput'] = 'Ingenting &aring; vise';
$lang['error_notemplate'] = 'Kan ikke finne malen';
$lang['error_dtdmismatch'] = 'DTD Versjon uoverenstemmelse, kan ikke importere';
$lang['import'] = 'Import ';
$lang['upload'] = 'Last opp Tema';
$lang['id'] = 'ID';
$lang['name'] = 'Navn';
$lang['export'] = 'Eksport';
$lang['submit'] = 'Utf&oslash;r';
$lang['friendlyname'] = 'Tema Behandler';
$lang['postinstall'] = 'Husk &aring; sette &quot;Manage Themes&quot; rettigheter for &aring; bruke denne modulen!';
$lang['uninstalled'] = 'Modul avinnstallert.';
$lang['installed'] = 'Modul versjon %s innstallert.';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dinne rettigheter.';
$lang['error'] = 'Feil!';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['moddescription'] = 'En modul for &aring; tillate import og eksport av innholds tema (maler og stilsett)';
$lang['import_succeeded'] = 'Temaet ble vellykket importert';
$lang['help'] = '<h3>Hva gj&oslash;r denne modulen?</h3>
<p>Denne modulen gj&oslash;r deg i stand til &aring; importere og eksportere sidemaler og deres vedlagte stilark som  &quot;temaer&quot;.  P&aring; denne m&aring;ten kan du dele useende og oppf&oslash;rsel med andre cms brukere.</p

<h3>Hvoran bruker jeg den?</h3>
<p>Denne modulen har ingen framside interface, bare et admin interface.  Det tillater deg &aring; velge en eksisterende (aktiv) mal, og klikke &quot;Eksport&quot;.  En XML fil inneholdende malen og dets vedlagte stilark blir laget og nedlastet til deg.</p>

<h3>Tillatelser</h3>
<p>Modellen for tillatelser er strenge for Temabehandler for &aring; sikre database integritet.  Tillatelsen &quot;Manage Themes&quot; kreves for &aring; kunne eksportere temaer, og disse tre tillatelsene  (&quot;Add Stylesheets&quot;, &quot;Add StyleSheet Assocations&quot;, og &quot;Add Templates&quot;) kreves for &aring; kunne importere et  tema.</p>
<p>Du kan ogs&aring; laste opp en tema fil (xml format) og f&aring; de innkluderte maler og stilark automatisk importert inn til din cmsms installasjon.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the module homepage at <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utmz'] = '156861353.1234296378.907.26.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,7.0.html';
$lang['utma'] = '156861353.179052623084110100.1210423577.1235686426.1235752139.968';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1235752139';
?>

==> cmsmadesimple-1.7.1-full.tar.gz: modules/ThemeManager/lang/ext/nb_NO.php <==
<?php
$lang['error_uploadpermissions'] = '<strong>ADVARSEL:</strong> Du har ikke tilstrekkelige rettigheter for &aring; laste opp eller installere temaer. Dette kan bero p&aring; restriksjoner satt p&aring; opplasting eller modulers underkataloger, eller ogs&aring; s&aring; kan Safe mode v&aelig;re aktivert p&aring; serveren.';
$lang['error_nomenumanager'] = 'MenuManager modulen ikke funnet';
$lang['active'] = 'Aktiv';
$lang['default'] = 'Standard';
$lang['prompt_themename'] = 'Eksporter Tema som:';
$lang['info_themename'] = 'Dette feltet bestemmer utg&aring;ende tema-navn, uavhengig av inng&aring;ende tema-navn';
$lang['error_editingproblem'] = 'Problem med &aring; rense opp og endre reffererte filer i dette tema&#039;et';
$lang['error_problemsavingincludes'] = 'Problem med &aring; lagere de enkodede filene i dette temaet..';
$lang['error_nofilesuploaded'] = 'Ingen filer ble lastet opp. Sjekk at din skjema tagg&#039;s enctype var satt til multipart/form-data og at korrekt felt er blitt haket av for den opplastede fila.';
$lang['error_templateexists'] = 'En mal med navnet &quot;%s&quot; eksisterer allerede';
$lang['error_stylesheetexists'] = 'Et stilsett med navnet &quot;%s&quot; eksisterer allerede';
$lang['error_nostylesheets'] = 'Ingen stilsett ble funnet i dette temaet';
$lang['error_couldnotcreatetemplate'] = 'Kunne ikke opprette mal-definisjonen';
$lang['error_couldnotassoccss'] = 'Problem med &aring; assosiere stilsett med malen';
$lang['error_nooutput'] = 'Ingenting &aring; vise';
$lang['error_notemplate'] = 'Kan ikke finne malen';
$lang['error_dtdmismatch'] = 'DTD Versjon uoverenstemmelse, kan ikke importere';
$lang['import'] = 'Import ';
$lang['upload'] = 'Last opp Tema (KUN .xml fil)';
$lang['id'] = 'ID';
$lang['name'] = 'Navn';
$lang['export'] = 'Eksport';
$lang['submit'] = 'Utf&oslash;r';
$lang['friendlyname'] = 'Tema Behandler';
$lang['postinstall'] = 'Husk &aring; sette &quot;Manage Themes&quot; rettigheter for &aring; bruke denne modulen!';
$lang['uninstalled'] = 'Modul avinnstallert.';
$lang['installed'] = 'Modul versjon %s innstallert.';
$lang['prefsupdated'] = 'Modul innstillinger oppdatert.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dinne rettigheter.';
$lang['error'] = 'Feil!';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['moddescription'] = 'En modul for &aring; tillate import og eksport av innholds tema (maler og stilsett)';
$lang['import_succeeded'] = 'Temaet ble vellykket importert';
$lang['help'] = '<h3>Hva gj&oslash;r denne modulen?</h3>
<p>Denne modulen gj&oslash;r deg i stand til &aring; importere og eksportere sidemaler og deres vedlagte stilark som  &quot;temaer&quot;.  P&aring; denne m&aring;ten kan du dele useende og oppf&oslash;rsel med andre cms brukere.</p

<h3>Hvoran bruker jeg den?</h3>
<p>Denne modulen har ingen framside interface, bare et admin interface.  Det tillater deg &aring; velge en eksisterende (aktiv) mal, og klikke &quot;Eksport&quot;.  En XML fil inneholdende malen og dets vedlagte stilark blir laget og nedlastet til deg.</p>

<h3>Tillatelser</h3>
<p>Modellen for tillatelser er strenge for Temabehandler for &aring; sikre database integritet.  Tillatelsen &quot;Manage Themes&quot; kreves for &aring; kunne eksportere temaer, og disse tre tillatelsene  (&quot;Add Stylesheets&quot;, &quot;Add StyleSheet Assocations&quot;, og &quot;Add Templates&quot;) kreves for &aring; kunne importere et  tema.</p>
<p>Du kan ogs&aring; laste opp en tema fil (xml format) og f&aring; de innkluderte maler og stilark automatisk importert inn til din cmsms installasjon.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the module homepage at <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utmz'] = '156861353.1240436806.1213.30.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/phpbbx';
$lang['utma'] = '156861353.179052623084110100.1210423577.1241225924.1241263552.1246';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.4.10.1241263552';
?>
